@@ -3,12 +3,12 @@
 from __future__ import unicode_literals, print_function, division
 
 # Static values
-__version__  = '3.11.0'
+__version__  = '3.12.1'
 NAME         = 'xml2rfc'
 VERSION      = [ int(i) if i.isdigit() else i for i in __version__.split('.') ]
 CACHES       = ['/var/cache/xml2rfc', '~/.cache/xml2rfc']  # Ordered by priority
 CACHE_PREFIX = ''
-NET_SUBDIRS  = ['bibxml', 'bibxml2', 'bibxml3', 'bibxml4', 'bibxml5']
+NET_SUBDIRS  = ['bibxml', 'bibxml-misc', 'bibxml-ids', 'bibxml-w3c', 'bibxml-3gpp', 'bibxml-ieee', 'bibxml-rfcsubseries']
 V3_PI_TARGET = 'v3xml2rfc'
 
 from xml2rfc.parser import  XmlRfcError, CachingResolver, XmlRfcParser, XmlRfc
